/*******************************************************
*        Trabalho de Inteligncia Artificial           *
*             Anderson de Rezende Rocha                *
*                 Jlio Csar Alves                    * 
*******************************************************/

#ifndef DEPOSITO_H
#define DEPOSITO_H

#include "ponto.h"

// Definio da classe depsito
class clDeposito
{
    public:
        // Construtores
        clDeposito();
        clDeposito(int umId, clPonto pos, int capacidadeMaxima, int quantidadeDeOuro = 0);
        // Construtor de cpia
        clDeposito(const clDeposito &deposito);
        ~clDeposito();
        void operator=(const clDeposito &deposito);

        // Retorna a posio de um deposito
        clPonto GetPosicao();
        // Identificador do deposito
        int GetId();
        // Quantidade atual de mineral neste deposito
        int GetQuantidade();
        // Capacidade deste deposito
        int GetCapacidade();
        // Verifica se o deposito est cheio ou no
        bool Cheio();
        // Deposita um mineral neste deposito
        bool DepositarOuro(int quantidadeDeOuro = 1);
        // Operador de igualdade
        bool operator==(clDeposito dep) { return (id == dep.id); }

    private:
        int id;
        clPonto posicao;
        int capacidade;
        int quantidade;
};

// Construtor
clDeposito::clDeposito()
{
    id = -1;
    posicao.Set(0,0);
    capacidade = 0;
    quantidade = 0;
}

// Destrutor
clDeposito::~clDeposito(){}

// Constri um deposito a partir de um identificador, posio, capacidade e quantidade 
// de minrio desejados
clDeposito::clDeposito(int umId, clPonto pos, int capacidadeMaxima, int quantidadeDeOuro)
{
    id = umId;
    posicao = pos;
    capacidade = capacidadeMaxima;
    quantidade = quantidadeDeOuro;
}

// Construtor de cpia
clDeposito::clDeposito(const clDeposito &deposito)
{
    id = deposito.id;
    posicao = deposito.posicao;
    capacidade = deposito.capacidade;
    quantidade = deposito.quantidade;
}

// Operador de igualdade. Permite comparar dois depositos
void clDeposito::operator=(const clDeposito &deposito)
{
    id = deposito.id;
    posicao = deposito.posicao;
    capacidade = deposito.capacidade;
    quantidade = deposito.quantidade;
}

// Retorna a posio do deposito no ambiente
clPonto clDeposito::GetPosicao()
{
    return posicao;
}


// Qual o identificador deste depsito?
int clDeposito::GetId()
{
    return id;
}


// Qual a quantidade atual deste depsito?
int clDeposito::GetQuantidade()
{
    return quantidade;
}

// Qual a capacidade deste depsito?
int clDeposito::GetCapacidade()
{
    return capacidade;
}

// O depsito j est cheio?
bool clDeposito::Cheio()
{
    return (quantidade == capacidade);
}

// Permite aumentar a quantidade de minrio atualmente neste depsito
bool clDeposito::DepositarOuro(int quantidadeDeOuro)
{
    if (quantidadeDeOuro <= (capacidade - quantidade))
    {
        quantidade += quantidadeDeOuro;
        return true;
    }
    return false;
}

#endif


